@@ -22,9 +22,9 @@ class DVFormWidget(IntEnum):
     DJVUE_INPUT_GROUP = 8,
 
 
-class DVFormLayout(IntEnum):
-    NONE = 0
-    INLINE = 1
+# class DVFormLayout(IntEnum):
+#     NONE = 0
+#     INLINE = 1
 
 
 class DVFormLabelAlign(Enum):
